NLSL: plgndr.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
plgndr.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
double precision function | plgndr (l, m, z)

## Function/Subroutine Documentation

double precision function plgndr | ( | integer | l,
|  | integer | m,
|  | double precision | z
| ) |  |

Definition at line 22 of file plgndr.f90.